include <MCAD/units.scad>;
include <MCAD/polyholes.scad>;

module lipoly(size, kapton, wire, wire_length = 20 * mm, wire_dia = 1.5 * mm) {
	// Battery
	color([0.7, 0.7, 0.7])
		cube([size[0] - kapton, size[1], size[2]]);

	// PCB
	board_thickness = 1.6 * mm;

	translate([size[0] - kapton, epsilon, (size[2] - board_thickness) / 2])
		color([0, 0.6, 0])
		cube([kapton - epsilon, size[1] - 2 * epsilon, board_thickness]);

	// Kapton
	translate([size[0] - kapton, 0, 0])
		color([0.8, 0.5, 0.2, 0.7])
		cube([kapton, size[1], size[2]]);

	// Wires
	translate([size[0], wire, size[2]/2])
		rotate([0, 90, 0])
		color([0.9, 0, 0])
		cylinder(d = wire_dia, h = wire_length);

	translate([size[0], size[1] - wire, size[2]/2])
		rotate([0, 90, 0])
		color([0, 0, 0])
		cylinder(d = wire_dia, h = wire_length);
}

// Begin lipoly case for traffic light

circle_dia = 5.025 * inch;
hole_sep = 86 * mm;
hole_dia = 3.5 * mm;

batt_size = [63 * mm, 48 * mm, 8 * mm];
case_size = [2.4 * mm, 2.4 * mm, 1.5 * mm];
wire_width = 10 * mm;

$fn = 180;

batt_max_x = sqrt(pow(circle_dia/2, 2) - pow(batt_size[1]/2, 2));

difference() {
	union() {
		// Mounting plate
		hull() {
			intersection() {
				cylinder(d = circle_dia, h = case_size[2]);

				translate([batt_max_x, -circle_dia, 1 + batt_size[2]] - batt_size - case_size)
					cube(batt_size + 2*case_size - X*case_size[0] + Y*2*circle_dia);

				rotate([0, 0, -45])
					cube([circle_dia, circle_dia, case_size[2]]);
			}

			translate([hole_sep/2, hole_sep/2, -epsilon])
				cylinder(d = circle_dia - hole_sep*sqrt(2), h = case_size[2] + 2*epsilon);

			translate([hole_sep/2, -hole_sep/2, -epsilon])
				polyhole(d = circle_dia - hole_sep*sqrt(2), h = case_size[2] + 2*epsilon);

			translate([batt_max_x, batt_size[1]/2, batt_size[2] + case_size[2]] - batt_size - case_size)
				cube([1, batt_size[1] + 2*case_size[1], case_size[2]]);
		}

		// Box body
		intersection() {
			translate([batt_max_x, batt_size[1]/2, case_size[2] + batt_size[2]] - batt_size - case_size)
				cube(batt_size + 2*case_size - X*case_size[0]);

			cylinder(d = circle_dia, h = batt_size[2] + 2*case_size[2]);
		}
	}

	// Mounting holes
	translate([hole_sep/2, hole_sep/2, -epsilon])
		polyhole(d = hole_dia, h = case_size[2] + 2*epsilon);

	translate([hole_sep/2, -hole_sep/2, -epsilon])
		polyhole(d = hole_dia, h = case_size[2] + 2*epsilon);

	// Battery insertion hole
	translate([batt_max_x, -batt_size[1]/2, -epsilon])
		cube([circle_dia - batt_size[0] + epsilon, batt_size[1], case_size[2] + 2*epsilon]);

	// Battery-sized hole
	translate([batt_max_x + epsilon, batt_size[1]/2, case_size[2]])
		rotate([0, 0, 180])
		cube(batt_size + epsilon*X);

	// Battery wire hole
	translate([0, 0, case_size[2] + batt_size[2]/2])
		cube([circle_dia, wire_width, batt_size[2]], center=true);
}

draw_batt = false;

if (draw_batt) {
	translate([batt_max_x + epsilon, batt_size[1]/2, case_size[2]])
		rotate([0, 0, 180])
		lipoly(batt_size, 8 * mm, 22 * mm);
}
